@@ -16,13 +16,28 @@
  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
  02110-1301, USA.
 
- $Id: gsl_userdef.h 778 2013-07-11 15:49:39Z micael $
 */
 
 #ifndef __GSL_USERDEF_H__
 #define __GSL_USERDEF_H__
 
-gsl_complex gsl_complex_step_real (double a);  /* Heaviside step function */
+/* Heaviside step function */
+gsl_complex gsl_complex_step_real (double a);
 
+/* Minimum and maximum of two arguments (comparing real parts) */  
+gsl_complex gsl_complex_min_real (gsl_complex a, gsl_complex b);
+gsl_complex gsl_complex_max_real (gsl_complex a, gsl_complex b);
+
+/* arg, abs, abs2 and logabs with complex return values for consistency */
+gsl_complex gsl_complex_carg  (gsl_complex a);
+gsl_complex gsl_complex_cabs  (gsl_complex a);
+gsl_complex gsl_complex_cabs2 (gsl_complex a);
+gsl_complex gsl_complex_clogabs (gsl_complex a);
+
+/* error function */
+gsl_complex gsl_complex_erf(gsl_complex a);
+
+/* atan2 function */
+gsl_complex gsl_complex_arctan2 (gsl_complex a, gsl_complex b);
 
 #endif /* __GSL_USERDEF_H__ */
